@@ -308,13 +308,13 @@ class WidgitEmbed:
                 await ctx.bot.wait_for("reaction_add", check=pred, timeout=30)
 
                 await self.editor_data["the_editor"].remove_reaction(
-                    the_options[pred.result], ctx.author
+                    the_options[pred.result], ctx.author  # type: ignore
                 )
 
-                if pred.result < len(supported):
-                    selected = list(supported)[pred.result]
-                else:
-                    result = pred.result - len(supported)
+                if supported and int(pred.result) < len(supported):  # type: ignore
+                    selected = list(supported)[int(pred.result)]  # type: ignore
+                if supported and int(pred.result) >= len(supported):  # type: ignore
+                    result = int(pred.result) - len(supported)  # type: ignore
 
                     if self.editor_data["inline"]:
                         selected = list(mandatory_inline)[result]
